import db from './db';

export const getItemsWithQuantities = () => {
  return new Promise((resolve, reject) => {
    db.transaction((tx) => {
      tx.executeSql('SELECT * FROM items', [], (_, { rows }) => {
        const items = rows._array;
        resolve(items);
      });
    });
  });
};

export const deleteItem = (itemId) => {
  return new Promise((resolve, reject) => {
    db.transaction((tx) => {
      tx.executeSql(
        'DELETE FROM items WHERE id = ?',
        [itemId],
        (_, result) => {
          console.log(`Item with ID ${itemId} deleted successfully`);
          resolve(result);
        },
        (error) => {
          console.log(`Error deleting item with ID ${itemId}:`, error);
          reject(error);
        }
      );
    });
  });
};


export const increaseQuantity = (itemId) => {
  return new Promise((resolve, reject) => {
    db.transaction((tx) => {
      tx.executeSql(
        'UPDATE items SET quantity = quantity + 1 WHERE id = ?',
        [itemId],
        (_, result) => {
          resolve(result);
        },
        (error) => {
          reject(error);
        }
      );
    });
  });
};


export const checkIfLocalItemExists = (apiId) => {
  return new Promise((resolve, reject) => {
    db.transaction((tx) => {
      tx.executeSql(
        'SELECT * FROM items WHERE id = ?',
        [apiId],
        (_, { rows: { _array } }) => {
          if (_array.length > 0) {
            resolve(_array[0]);
          } else {
            resolve(null);
          }
        },
        (_, error) => {
          reject(error);
        }
      );
    });
  });
};

export const updateLocalItemQuantity = (item_id, newQuantity) => {
  return new Promise((resolve, reject) => {
    db.transaction((tx) => {
      tx.executeSql(
        'UPDATE items SET quantity = ? WHERE id = ?',
        [newQuantity, item_id],
        (_, results) => {
          console.log(`Item with ID ${item_id} updated in the local db (quantity: ${newQuantity})`);
          resolve(results);
        },
        (error) => {
          console.log('Error updating item in the local database:', error);
          reject(error);
        }
      );
    });
  });
};

export const decreaseQuantity = (itemId) => {
  return new Promise((resolve, reject) => {
    db.transaction((tx) => {
      tx.executeSql(
        'UPDATE items SET quantity = CASE WHEN quantity > 1 THEN quantity - 1 ELSE 1 END WHERE id = ?',
        [itemId],
        (_, result) => {
          resolve(result);
        },
        (error) => {
          reject(error);
        }
      );
    });
  });
};

export const insertItem = (apiId, name, price) => {
  return new Promise((resolve, reject) => {
    db.transaction((tx) => {
      tx.executeSql(
        'INSERT INTO items (id, name, price, quantity) VALUES (?, ?, ?, ?)',
        [apiId, name, price, 1],
        (_, results) => {
          console.log(`Item ${name} added in local db (quantity: 1)`);
          resolve(results);
        },
        (error) => {
          console.log('Error adding item to local database:', error);
          reject(error);
        }
      );
    });
  });
};
