import React, { useEffect, useState } from 'react';
import { View, Text, FlatList, StyleSheet } from 'react-native';
import Styles from '../styles/Style';
import { format } from 'date-fns';
import { getPaymentsHistory } from '../database/dbUtils';
import AsyncStorage from '@react-native-async-storage/async-storage';
import Constants from 'expo-constants';

export default function PaymentHistoryScreen() {
  const [paymentHistory, setPaymentHistory] = useState([]);
  const [isDarkMode, setIsDarkMode] = useState(false);
  const apiUrl = Constants.manifest.extra.apiUrl;
  const customerId = "cus_OsU6FAKAAXp1YI";

  const retrieveThemeMode = async () => {
    try {
      const themeMode = await AsyncStorage.getItem('themeMode');
      if (themeMode !== null) {
        setIsDarkMode(themeMode === 'dark');
      }
    } catch (error) {
      console.log('Error retrieving theme mode:', error);
    }
  };

  useEffect(() => {
    retrieveThemeMode();
    loadPaymentHistory();
  }, []);

  const loadPaymentHistory = async () => {
    try {
      const response = await fetch(`${apiUrl}/payments/${customerId}`);
      if (response.ok) {
        const history = await response.json();
        setPaymentHistory(history);
      } else {
        console.log('Error while retrieving payments history');
      }
    } catch (error) {
      console.log('Error while retrieving payments history', error);
    }
  };

  return (
    <View style={isDarkMode ? Styles.darkContainer : Styles.lightContainer}>
      <FlatList
        data={paymentHistory}
        keyExtractor={(item) => item.id}
        renderItem={({ item }) => (
          <View style={Styles.historyItem}>
            <Text style={Styles.itemName}>{item.purchased_items[0].item.name}</Text>
            <Text style={Styles.itemDate}>
              {format(new Date(item.checkout_date), 'MMMM dd, yyyy HH:mm a')}
            </Text>
            <Text style={Styles.itemPrice}>
              {(item.purchased_items[0].item.price / 100).toFixed(2)} €
            </Text>
          </View>
        )}
      />
    </View>
  );
}
